@@ -15,8 +15,11 @@
 #ifdef  __cplusplus
 extern "C" {
 #endif
-BOOL	LIBPQ_check(void);
+
+BOOL	SSLLIB_check(void);
+#ifndef	NOT_USE_LIBPQ
 void	*CALL_PQconnectdb(const char *conninfo, BOOL *);
+#endif /* NOT_USE_LIBPQ */
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 RETCODE	CALL_EnlistInDtc(ConnectionClass *conn, void * pTra, int method);
 RETCODE	CALL_DtcOnDisconnect(ConnectionClass *);
