@@ -399,7 +399,7 @@ SQLFetch(HSTMT StatementHandle)
 		mylog("[[%s]]", func);
 		ret = PGAPI_ExtendedFetch(StatementHandle, SQL_FETCH_NEXT, 0,
 								   pcRow, rowStatusArray, 0, ardopts->size_of_rowset);
-		stmt->transition_status = 6;
+		stmt->transition_status = STMT_TRANSITION_FETCH_SCROLL;
 	}
 	else
 #endif
@@ -639,15 +639,21 @@ RETCODE		SQL_API
 SQLPrepare(HSTMT StatementHandle,
 		   SQLCHAR *StatementText, SQLINTEGER TextLength)
 {
+	CSTR func = "SQLPrepare";
 	RETCODE	ret;
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 
 	mylog("[SQLPrepare]");
 	ENTER_STMT_CS(stmt);
 	SC_clear_error(stmt);
-	StartRollbackState(stmt);
-	ret = PGAPI_Prepare(StatementHandle, StatementText, TextLength);
-	ret = DiscardStatementSvp(stmt, ret, FALSE);
+	if (SC_opencheck(stmt, func))
+		ret = SQL_ERROR;
+	else
+	{
+		StartRollbackState(stmt);
+		ret = PGAPI_Prepare(StatementHandle, StatementText, TextLength);
+		ret = DiscardStatementSvp(stmt, ret, FALSE);
+	}
 	LEAVE_STMT_CS(stmt);
 	return ret;
 }
@@ -1130,7 +1136,7 @@ SQLExtendedFetch(
 #else
 	ret = PGAPI_ExtendedFetch(hstmt, fFetchType, irow, pcrow, rgfRowStatus, 0, SC_get_ARDF(stmt)->size_of_rowset_odbc2);
 #endif /* WITH_UNIXODBC */
-	stmt->transition_status = 7;
+	stmt->transition_status = STMT_TRANSITION_EXTENDED_FETCH;
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS(stmt);
 	return ret;
