@@ -389,8 +389,8 @@ static BOOL CheckHasOids(StatementClass * stmt)
 				TI_set_hasoids(ti);
 				foundKey = TRUE;
 				STR_TO_NAME(ti->bestitem, OID_NAME);
-				sprintf(query, "\"%s\" = %u", OID_NAME);
-				STR_TO_NAME(ti->bestqual, query);
+				sprintf(query, "\"%s\" = %%u", OID_NAME);
+				STRX_TO_NAME(ti->bestqual, query);
 			}
 			TI_set_hasoids_checked(ti);
 			ti->table_oid = (OID) strtoul(QR_get_value_backend_text(res, 0, 1), NULL, 10);
@@ -410,7 +410,7 @@ static BOOL CheckHasOids(StatementClass * stmt)
 					strcat(query, "d");
 				else
 					strcat(query, "u");
-				STR_TO_NAME(ti->bestqual, query);
+				STRX_TO_NAME(ti->bestqual, query);
 			}
 			else
 			{
@@ -544,7 +544,7 @@ static void xxxxx(FIELD_INFO *fi, QResultClass *res, int i)
 	}
 }
 
-static has_multi_table(const StatementClass *stmt)
+static BOOL has_multi_table(const StatementClass *stmt)
 {
 	BOOL multi_table = FALSE;
 	QResultClass	*res;
@@ -974,7 +974,7 @@ SC_set_SS_columnkey(StatementClass *stmt)
 	IRDFields	*irdflds = SC_get_IRDF(stmt);
 	FIELD_INFO	**fi = irdflds->fi, *tfi;
 	size_t		nfields = irdflds->nfields;
-	StatementClass	*pstmt = NULL;
+	HSTMT		pstmt = NULL;
 	SQLRETURN	ret = SQL_SUCCESS;
 	BOOL		contains_key = FALSE;
 	int		i;
@@ -1132,14 +1132,14 @@ parse_the_statement(StatementClass *stmt, BOOL check_hasoids, BOOL sqlsvr_check)
 				k = 0,
 				n,
 				blevel = 0, old_blevel, subqlevel = 0,
-				tbl_blevel = 0, allocated_size, new_size,
+				tbl_blevel = 0, allocated_size = -1, new_size,
 				nfields;
 	FIELD_INFO **fi, *wfi;
 	TABLE_INFO **ti, *wti;
-	char		parse, maybe_join = 0;
+	char		parse = FALSE, maybe_join = 0;
 	ConnectionClass *conn = SC_get_conn(stmt);
 	IRDFields	*irdflds;
-	BOOL		updatable = TRUE, column_has_alias;
+	BOOL		updatable = TRUE, column_has_alias = FALSE;
 
 	mylog("%s: entering...\n", func);
 
@@ -1175,7 +1175,7 @@ parse_the_statement(StatementClass *stmt, BOOL check_hasoids, BOOL sqlsvr_check)
 
 	delim = '\0';
 	token[0] = '\0';
-	while (pptr = ptr, (delim != ',') ? strcpy(btoken, token) : (char *) (btoken[0] = '\0'), (ptr = getNextToken(conn->ccsc, CC_get_escape(conn), pptr, token, sizeof(token), &delim, &quote, &dquote, &numeric)) != NULL)
+	while (pptr = ptr, (delim != ',') ? strcpy(btoken, token) : (btoken[0] = '\0', NULL), (ptr = getNextToken(conn->ccsc, CC_get_escape(conn), pptr, token, sizeof(token), &delim, &quote, &dquote, &numeric)) != NULL)
 	{
 		unquoted = !(quote || dquote);
 
@@ -1310,7 +1310,7 @@ mylog("blevel=%d btoken=%s in_dot=%d in_field=%d tbname=%s\n", blevel, btoken, i
 
 					column_has_alias = TRUE;
 					if (NULL != wfi)
-						STR_TO_NAME(wfi->column_alias, token);
+						STRX_TO_NAME(wfi->column_alias, token);
 					news = insert_as_to_the_statement(stmt->statement, &pptr, &ptr);
 					if (news != stmt->statement)
 					{
@@ -1435,7 +1435,7 @@ mylog("blevel=%d btoken=%s in_dot=%d in_field=%d tbname=%s\n", blevel, btoken, i
 				}
 				else if (NULL != wfi)
 				{
-					STR_TO_NAME(wfi->column_name, token);
+					STRX_TO_NAME(wfi->column_name, token);
 					NULL_THE_NAME(wfi->before_dot);
 				}
 				if (NULL != wfi)
@@ -1465,7 +1465,7 @@ mylog("blevel=%d btoken=%s in_dot=%d in_field=%d tbname=%s\n", blevel, btoken, i
 						MOVE_NAME(wfi->schema_name, wfi->before_dot);
 					}
 					MOVE_NAME(wfi->before_dot, wfi->column_name);
-					STR_TO_NAME(wfi->column_name, token);
+					STRX_TO_NAME(wfi->column_name, token);
 				}
 
 				if (delim == ',')
@@ -1482,7 +1482,7 @@ mylog("blevel=%d btoken=%s in_dot=%d in_field=%d tbname=%s\n", blevel, btoken, i
 				column_has_alias = TRUE;
 				if (NULL != wfi)
 				{
-					STR_TO_NAME(wfi->column_alias, token);
+					STRX_TO_NAME(wfi->column_alias, token);
 					mylog("alias for field '%s' is '%s'\n", PRINT_NAME(wfi->column_name), PRINT_NAME(wfi->column_alias));
 				}
 				in_as = FALSE;
@@ -1607,7 +1607,7 @@ mylog("blevel=%d btoken=%s in_dot=%d in_field=%d tbname=%s\n", blevel, btoken, i
 				{
 					if (is_table_name)
 					{
-						STR_TO_NAME(wti->table_name, token);
+						STRX_TO_NAME(wti->table_name, token);
 						lower_the_name(GET_NAME(wti->table_name), conn, dquote);
 						mylog("got table = '%s'\n", PRINT_NAME(wti->table_name));
 					}
@@ -1684,7 +1684,7 @@ mylog("blevel=%d btoken=%s in_dot=%d in_field=%d tbname=%s\n", blevel, btoken, i
 					if (NULL != wfi)
 					{
 						MOVE_NAME(wti->schema_name, wti->table_name);
-						STR_TO_NAME(wti->table_name, token);
+						STRX_TO_NAME(wti->table_name, token);
 						lower_the_name(GET_NAME(wti->table_name), conn, dquote);
 					}
 					in_dot = FALSE;
@@ -1707,7 +1707,7 @@ mylog("blevel=%d btoken=%s in_dot=%d in_field=%d tbname=%s\n", blevel, btoken, i
 					}
 					if (NULL != wti)
 					{
-						STR_TO_NAME(wti->table_alias, token);
+						STRX_TO_NAME(wti->table_alias, token);
 						mylog("alias for table '%s' is '%s'\n", PRINT_NAME(wti->table_name), PRINT_NAME(wti->table_alias));
 					}
 					in_table = FALSE;
